locals {
  local_statemachine_definition = replace(var.statemachine_definition, "LAMBDA_ARN", var.lambda_arn)
}

resource "aws_sfn_state_machine" "sfn_state_machine" {
  name       = var.statemachine_name
  role_arn   = var.role_arn
  definition = local.local_statemachine_definition

  tags = var.tags

  logging_configuration {
    log_destination        = "${aws_cloudwatch_log_group.sfn_log_group.arn}:*"
    include_execution_data = true
    level                  = "ERROR"
  }
}

resource "aws_iam_policy" "step-function-policy" {
  count       = var.enable_iam_policies ? 1 : 0
  name        = "${var.iam_policy_prefix}-step-function-policy"
  path        = "/"
  description = "Step Function policy"

  policy = <<EOF
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Action": [
        "states:StartExecution",
        "states:DescribeStateMachine",
        "states:ListExecutions",
        "states:StopExecution"
      ],
      "Effect": "Allow",
      "Resource": "${aws_sfn_state_machine.sfn_state_machine.arn}"
    }
  ]
}
EOF
  lifecycle {
    ignore_changes = [
      description,
    ]
  }
  tags = var.tags
}

resource "aws_cloudwatch_log_group" "sfn_log_group" {
  name              = "/aws/vendedlogs/states/${var.statemachine_name}"
  retention_in_days = var.cloudwatch_retention
  tags              = var.tags
}
